"""
types-confluent-kafka: A package providing type hints for the confluent-kafka Python package.
This package is licensed under the Apache 2.0 License.
"""
from __future__ import annotations

from .conversion_util import ConversionUtil as ConversionUtil
from .validation_util import ValidationUtil as ValidationUtil
