"""
types-confluent-kafka: A package providing type hints for the confluent-kafka Python package.
This package is licensed under the Apache 2.0 License.

Python client implementations of the official Kafka tests/kafkatest clients.
"""
from __future__ import annotations
